pub trait Analyzer {
// Required methods
fn get_version(&self, ciphertext: &str) -> Result<ClientVersion, String>;
fn str_to_version(
&self,
client_version: &str,
) -> Result<ClientVersion, String>;
}Expand description
This trait supplies the function to use something as an analyzer. The main function of an analzyer object is to determine which client version a cipher text is using.
Required Methods
Sourcefn get_version(&self, ciphertext: &str) -> Result<ClientVersion, String>
fn get_version(&self, ciphertext: &str) -> Result<ClientVersion, String>
Get the client version a cipher text is using.
Sourcefn str_to_version(&self, client_version: &str) -> Result<ClientVersion, String>
fn str_to_version(&self, client_version: &str) -> Result<ClientVersion, String>
Parse a string and return the client version enumeration number.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".